@@ -53,7 +53,7 @@ define('oxguard/core/confirmView', [
         .on('cancel', function () {
             def.reject();
         })
-        .addButton()
+        .addCloseButton()
         .open();
     }
 
