@@ -7,8 +7,8 @@
  *
  * Copyright (C) 2016-2020 OX Software GmbH
  */
-define('oxguard/core/og_http', [
-], function () {
+define('oxguard/core/og_http', [], function () {
+
     'use strict';
 
     function doPost(url, params, data, json) {
@@ -114,6 +114,7 @@ define('oxguard/core/og_http', [
                         }
                     }
                 }
+                data.keyIndex = window.oxguarddata.pubKey.index;
             }
             doPost(url, params, data, json)
             .done(function (e) {
