@@ -99,7 +99,7 @@ define('oxguard/core/passwordPrompt', [
         .build(function () {
         })
         .addButton({ label: 'OK', action: 'ok' })
-        .addButton()
+        .addCloseButton()
         .on('cancel', function () {
             def.reject('cancel');
         })
