@@ -172,7 +172,7 @@ define('oxguard/core/tempPassword', [
                         window.oxguarddata.new = false;
                         // Complete, now offer tour
                         require(['io.ox/core/capabilities', 'io.ox/core/tk/wizard', 'oxguard/tour/main'], function (capabilities, Tour) {
-                            if (capabilities.has('guard-mail')) { // only run tour if has guard-mail
+                            if (capabilities.has('guard-mail') && !capabilities.has('guest')) { // only run tour if has guard-mail
                                 Tour.registry.get('default/oxguard/createKeys').get('run')();
                             }
                         });
