@@ -6,6 +6,7 @@
  *
  * Copyright (C) 2016-2020 OX Software GmbH
  */
+
 define('oxguard/mail/checker', [
     'io.ox/core/extensions',
     'io.ox/core/extPatterns/links',
@@ -13,13 +14,13 @@ define('oxguard/mail/checker', [
     'oxguard/oxguard_core',
     'io.ox/core/capabilities'
 ], function (ext, links, http, core, capabilities) {
+
     'use strict';
 
     var firstload = true;
 
     // Do the check if the email is PGP email.  Check for inline, MIME, or signature
     function checkPGP(baton, location) {
-
         if (baton.data.security && baton.data.security.decrypted) {
             if (window.oxguarddata.settings.oxguard === false && !capabilities.has('guest')) { // If not guard user, display upsell if any
                 var loc = baton.view.$el;
@@ -44,8 +45,7 @@ define('oxguard/mail/checker', [
         }
         var mail = baton.data;
         if (mail.results !== undefined) return;
-        var attachments = baton.data.attachments;
-        if (attachments === undefined) return;
+
         if (headers['X-OXGUARD-GUEST'] !== undefined) {
             baton.view.model.set('pgp_found', true);
             pgpAttach(baton);
@@ -91,7 +91,10 @@ define('oxguard/mail/checker', [
                 if (baton.sessionKey) { // If local decrypt, save the sessionKey for attachments, etc
                     data.security.sessionKey = baton.sessionKey;
                 }
+                var origData = _.extend(baton.data, {});
                 baton.model.set(data);
+                origData.view = baton.view;
+                baton.model.set('origMail', origData);
                 // Update the pool mail with the attachment and security data of the email.  Otherwise will
                 // be overwritten with changes in listViews, sort order, etc
                 var stored = api.pool.get('detail').get(_.cid(data));
