@@ -6,8 +6,12 @@
  *
  * Copyright (C) 2016-2020 OX Software GmbH
  */
-define('oxguard/mail/mailReplyActions', ['settings!oxguard', 'io.ox/core/extensions'
+
+define('oxguard/mail/mailReplyActions', [
+    'settings!oxguard',
+    'io.ox/core/extensions'
 ], function (settings, ext) {
+
     'use strict';
 
     ext.point('io.ox/mail/compose/boot').extend({
@@ -27,6 +31,7 @@ define('oxguard/mail/mailReplyActions', ['settings!oxguard', 'io.ox/core/extensi
         index: 1001,
         perform: function (baton) {
             if (baton.data.original && baton.data.original.security && baton.data.original.security.decrypted) {
+                baton.view.securityModel.set('authToken', baton.data.original.security.authentication, true);
                 baton.view.securityModel.set('encrypt', true);
             }
             if (baton.data.type === 'reply' || baton.data.type === 'replyall' || baton.data.type === 'forward') {
@@ -37,7 +42,7 @@ define('oxguard/mail/mailReplyActions', ['settings!oxguard', 'io.ox/core/extensi
             }
             if (baton.model.get('security').encrypt) {
                 require(['oxguard/util'], function (util) {
-                    if (!util.hasGuardMailCapability()) {
+                    if (!util.hasGuardMailCapability() || util.isGuest()) {
                         baton.view.toggleEncryption.forceEncryption();
                         disableRecipients(baton.view);
                     }
@@ -73,7 +78,7 @@ define('oxguard/mail/mailReplyActions', ['settings!oxguard', 'io.ox/core/extensi
                         if (baton.view.securityModel.get('encrypt')) baton.view.securityModel.set('PGPFormat', (value ? 'inline' : 'mime'));
                         break;
                     default:
-                        console.error('Unkown security parameter ' + s[0]);
+                        console.error('Unknown security parameter ' + s[0]);
                 }
             });
             if (obj.security.authentication) {
