@@ -53,7 +53,7 @@ define('oxguard/mail/options_new', [
             .on('ok', function () {
                 baton.config.set('editorMode', 'text');
                 baton.config.on('change:editorMode', function () {
-                    if ((baton.model.get('editorMode') === 'html') && (baton.view.securityModel.get('PGPFormat') === 'inline')) {
+                    if ((baton.config.get('editorMode') === 'html') && (baton.view.securityModel.get('PGPFormat') === 'inline')) {
                         var dialog2 = new dialogs.CreateDialog({ width: 450, height: 300, center: true });
                         dialog2.header($('<h4>').text(gt('HTML Formatted Email')));
                         var warn = $('<p>').append(gt('HTML format is not recommended when using PGP Inline'));
