@@ -7,6 +7,7 @@
  *
  * Copyright (C) 2016-2020 OX Software GmbH
  */
+
 define('oxguard/mail/oxguard_mail_compose_core', [
     'io.ox/core/extensions',
     'oxguard/core/og_http',
@@ -17,6 +18,7 @@ define('oxguard/mail/oxguard_mail_compose_core', [
     'gettext!oxguard',
     'less!oxguard/mail/style'
 ], function (ext, og_http, notify, util, settings, dialogs, gt) {
+
     'use strict';
 
     //#. %s product name
@@ -41,31 +43,31 @@ define('oxguard/mail/oxguard_mail_compose_core', [
                     } else {
                         key.addClass('untrusted_key');
                     }
-                    createTooltip(info.key, key);
+                    createTooltip(info.key, key, location);
                     $(location).find('.close').before(key);
                     break;
                 case 'new' :
                     key.addClass('trusted_key');
                     $(location).find('.close').before(key);
-                    createTooltip('new', key);
+                    createTooltip('new', key, location);
                     break;
                 case 'guest' :
                     var gKey = $(guesticon);
                     $(location).find('.close').before(gKey);
-                    createTooltip('guest', gKey);
+                    createTooltip('guest', gKey, location);
                     break;
                 case 'fail' :
                     $(location).find('.close').before(failicon);
 
                     break;
                 default:
-                    console.error('Unkown key type ' + info.result);
+                    console.error('Unknown key type ' + info.result);
             }
         }
         input.width(inputwidth);
     }
 
-    function createTooltip(data, loc) {
+    function createTooltip(data, loc, t) {
         require(['oxguard/pgp/keyDetails'], function (pubKeys) {
             var div = $('<div>');
             if (data === 'new') {  // New recipient
@@ -81,13 +83,16 @@ define('oxguard/mail/oxguard_mail_compose_core', [
             }
             $(loc).tooltip({
                 title: div.html(),
-                trigger: 'hover',
+                trigger: 'hover focus',
                 placement: 'bottom',
                 html: true,
                 delay: 200,
                 animation: true,
                 viewport: { selector: '.io-ox-mail-compose', padding: 10 }
             });
+            var id = 'div' + (data.id ? data.id : Math.random());
+            $(loc).append($('<div id="' + id + '" class="sr-only srdetails">').html(div.html()));
+            t.attr('aria-describedby', id + ' ' + t.attr('aria-describedby'));
         });
     }
 
@@ -143,7 +148,7 @@ define('oxguard/mail/oxguard_mail_compose_core', [
                         checkrecipient(baton);
                     })
                     .fail(function () {
-                        unlock(baton);
+                        baton.view.securityModel.set('encrypt', false);
                     })
                     .always(function () {
                         prompting = false;
@@ -170,18 +175,19 @@ define('oxguard/mail/oxguard_mail_compose_core', [
         }
         baton.view.$el.find('.oxguard_key').hide();
         baton.view.$el.find('.oxguard_token').hide();
+        baton.view.$el.find('.oxguard_token .srdetails').remove();
     }
 
     function lock(baton) {
         if (_.device('smartphone')) {
             $('.btn-primary:visible').html((settings.get('advanced') ? gt('Send Encrypted') : gt('Send Secure')));
         } else {
-            var headerview = baton.view.app.get('window').nodes.header;
-            var footerview = baton.view.app.get('window').nodes.footer;
-            headerview.find('.btn-primary:visible').html((settings.get('advanced') ? gt('Send Encrypted') : gt('Send Secure')));
-            if (footerview) {
-                footerview.find('.btn-primary:visible').html((settings.get('advanced') ? gt('Send Encrypted') : gt('Send Secure')));
-            }
+            // var headerview = baton.view.app.get('window').nodes.header;
+            // var footerview = baton.view.app.get('window').nodes.footer;
+            // headerview.find('.btn-primary:visible').html((settings.get('advanced') ? gt('Send Encrypted') : gt('Send Secure')));
+            // if (footerview) {
+            //     footerview.find('.btn-primary:visible').html((settings.get('advanced') ? gt('Send Encrypted') : gt('Send Secure')));
+            // }
         }
         checkrecipient(baton);
         baton.view.$el.find('.oxguard_key').show();
