@@ -95,10 +95,10 @@ define('oxguard/mail/register_compose', [
                 .find('ul').prepend(
                     new HelpView({
                         base: 'help',
-                        iconClass: 'guardhelp fa-question-circle fa',
+                        iconClass: 'fa-question-circle',
                         href: 'ox.appsuite.user.sect.guard.email.send.html',
                         tabindex: '-1'
-                    }).render().$el.addClass('guard-help-icon')
+                    }).render().$el.addClass('guard-help-icon').addClass('guardhelp')
                 );
 
             node.append(dropdown.$el);
@@ -153,12 +153,14 @@ define('oxguard/mail/register_compose', [
                     intermediateModel.set(key, securityModel.get(key));
                 });
             });
-
-            this.data('view')
+            var node = this.data('view')
                 .divider()
-                .header(gt('Security'))
-                .option('PGPSignature', true, gt('Sign email'))
-                .option('PubKey', true, gt('Attach my public key'));
+                .header(gt('Security'));
+            if (util.hasGuardMailCapability()) {
+                node.option('PGPSignature', true, gt('Sign email'));
+            }
+            node.option('PubKey', true, gt('Attach my public key'));
+
         }
     });
 
