@@ -1,5 +1,13 @@
-define('oxguard/mail/util', [
-], function () {
+/* All content on this website (including text, images, source
+ * code and any other original works), unless otherwise noted,
+ * is licensed under a Creative Commons License.
+ *
+ * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
+ * Copyright (C) 2016-2020 OX Software GmbH
+ */
+
+define('oxguard/mail/util', [], function () {
     'use strict';
 
     var util = {};
