@@ -6,8 +6,11 @@
  *
  * Copyright (C) 2016-2020 OX Software GmbH
  */
-define('oxguard/office/register-mail', ['oxguard/pgp/register'
+
+define('oxguard/office/register-mail', [
+    'oxguard/pgp/register'
 ], function (registration) {
+
     'use strict';
 
     require(['io.ox/office/text/app/mailactions']).then(function () {
