@@ -14,6 +14,7 @@ define('oxguard/oxguard_core', [
     'io.ox/core/api/user',
     'gettext!oxguard'
 ], function (settings, guardSettings, og_http, userAPI, gt) {
+
     'use strict';
 
     var badCount = 0;
@@ -320,8 +321,23 @@ define('oxguard/oxguard_core', [
         }
     }
 
+    // Simple call to verify password.  Keyid optional
+    function verifyPassword(password, keyid) {
+        return authorize(undefined, password, undefined, keyid).then(function (data) {
+            if (data.auth && data.auth.length > 20) {
+                return; // Good auth
+            }
+            require(['oxguard/auth'], function (auth) {
+                auth.handleFail(data.auth);
+            });
+            return $.Deferred.reject();
+        });
+    }
+
+
     return {
         auth: authorize,
+        verifyPassword: verifyPassword,
         validateEmail: validateEmail,
         getPassword: getpassword,
         showError: showError,
