@@ -6,6 +6,7 @@
  *
  * Copyright (C) 2016-2020 OX Software GmbH
  */
+
 define('oxguard/pgp/register', [
     'io.ox/core/extensions',
     'io.ox/backbone/views/actions/util',
@@ -22,6 +23,7 @@ define('oxguard/pgp/register', [
     'oxguard/mail/mailReplyActions',
     'less!oxguard/pgp/style'
 ], function (ext, actionsUtil, http, checker, account, capabilities, util, metrics, mailExtensions, auth_core, settings, gt) {
+
     'use strict';
 
     // Draw security icons in mail detail view
@@ -40,18 +42,25 @@ define('oxguard/pgp/register', [
             this.append(pgp);
         }
         if (security.signatures) {
-            var sig = security.signatures[0];
+            var verified = true;
+            var error;
+            var missing = false;
+            security.signatures.forEach(function (sig) {
+                verified = verified && sig.verified;
+                if (sig.missing) missing = true;
+                if (sig.error) error = sig.error;
+            });
             var signedicon;
-            if (sig.verified) {
+            if (verified) {
                 signedicon = $('<i class="oxguard_icon_fa fa-pencil-square-o fa guard_signed" aria-hidden="true" title="' + gt('This Email was signed and verified.') + '"/>');
-            } else if (!sig.missing) {
+            } else if (!missing && !error) {
                 signedicon = $('<i class="oxguard_icon_fa_error fa-pencil-square fa guard_signed" aria-hidden="true" title="' + gt('This Email was signed and failed verification.') + '"/>');
             }
-            if (sig.missing) {
+            if (missing) {
                 signedicon = $('<i class="oxguard_icon_fa fa-pencil-square-o fa guard_signed" style="color:lightgrey" aria-hidden="true" title="' + gt('This Email was signed but unable to verify.') + '"/>');
             }
-            if (sig.error) {
-                signedicon = $('<i class="oxguard_icon_fa_error fa-pencil-square fa guard_signed" aria-hidden="true" title="' + gt('Error verifying signature: %s', sig.error) + '"/>');
+            if (error) {
+                signedicon = $('<i class="oxguard_icon_fa_error fa-pencil-square fa guard_signed" aria-hidden="true" title="' + gt('Error verifying signature: %s', error) + '"/>');
             }
             if (_.device('small')) {
                 signedicon.css('margin-right', '10px');
@@ -71,6 +80,59 @@ define('oxguard/pgp/register', [
         }
     }
 
+    // If so configured, cleanup any opened Guard emails
+    function cleanGuardCache(baton) {
+        if (settings.get('wipe') !== 'true') {  // If not configured to do so, exit
+            return;
+        }
+        var oxguarddata = window.oxguarddata;
+        if (oxguarddata && oxguarddata.passcode) {  // Don't wipe if still authenticated
+            return;
+        }
+        require(['io.ox/mail/api', 'io.ox/mail/main'], function (mailApi, mailMain) {
+            if (!mailApi.pool) return;
+            if (baton.options && baton.options.name === 'io.ox/mail/compose') {  // Don't wipe when just opening compose
+                return;
+            }
+            var collection = mailApi.pool.get('detail');
+            if (collection && collection.models) {
+                collection.models.forEach(function (model) {
+                    var security = model.get('security');
+                    if (security && security.decrypted) {
+                        var found = false;
+                        if (baton.model) {  // Still within mail application
+                            if (model.get('cid') === baton.model.cid) {  // Don't wipe the active mail
+                                found = true;
+                            }
+                            var mailApp = mailMain.getApp();
+                            if (mailApp.isThreaded()) {
+                                mailApp.threadView.collection.models.forEach(function (thrModel) {
+                                    if (thrModel.get('cid') === model.cid) {
+                                        found = true;
+                                    }
+                                });
+                            }
+                        }
+                        if (!found && model.get('origMail')) {
+                            var orig = model.get('origMail');
+                            model.clear();
+                            model.set(orig);
+                            var view = model.get('view');
+                            if (view.$el) {  // when changing apps, need to redraw
+                                view.redraw();
+                            }
+                        }
+                    }
+                });
+            }
+        });
+    }
+
+    if (capabilities.has('webmail')) {  // Register mail cleanup only if has mail
+        ox.on('app:start', cleanGuardCache);
+        ox.on('app:resume', cleanGuardCache);
+    }
+
     ext.point('io.ox/mail/detail/header').extend({
         id: 'guardNotices',
         index: 'last',
@@ -99,21 +161,6 @@ define('oxguard/pgp/register', [
         }
     });
 
-    // Detail View Extensions
-    ext.point('io.ox/mail/detail/body').extend({
-        id: 'guardCheck',
-        index: 1,
-        draw: function (baton) {
-            if (baton.data.PGP) {  // If drawing a PGP email, and already decoded
-                // Check if this is a reload, resulting in the attachments changing
-                if (baton.data.attachments[0] && !baton.data.attachments[0].pgpFormat) {
-                    baton.attachments = baton.data.decodedAttachments;
-                    baton.data.attachments = baton.data.decodedAttachments;
-                }
-            }
-        }
-    });
-
     ext.point('io.ox/mail/detail/attachments').extend({
         id: 'ogCheck',
         index: 1,
@@ -138,6 +185,7 @@ define('oxguard/pgp/register', [
             if (baton.data.security_info && baton.data.security_info.encrypted) {
                 baton.stopPropagation();
                 checkAutocryptHeaders(baton);  // Check headers for the encrypted emails
+                cleanGuardCache(baton); // Clean previously decrypted emails
             }
         }
     });
@@ -174,6 +222,32 @@ define('oxguard/pgp/register', [
         }
     });
 
+    ext.point('io.ox/mail/detail/body').extend({
+        index: 'last',
+        id: 'cleanup',
+        draw: function (baton) {
+            cleanGuardCache(baton);
+        }
+    });
+
+    //  Wipe previews for encrypted emails
+    function wipePreview(baton) {
+        if (baton.data.text_preview) {
+            if (baton.data.content_type && baton.data.content_type.indexOf('encrypted') > 0) {
+                baton.data.text_preview = '';
+            }
+            if (baton.data.text_preview.indexOf('----BEGIN PGP') > -1) {
+                baton.data.text_preview = '';
+            }
+        }
+    }
+
+    ext.point('io.ox/mail/listview/item').extend({
+        id: 'guard-preview',
+        index: 10,
+        draw: wipePreview
+    });
+
     // Add lock to header
     ext.point('io.ox/mail/detail/header').extend({
         index: 230,
