@@ -158,7 +158,7 @@ define('oxguard/register', [
         id: 'guard-guided-tour',
         index: 290,
         extend: function () {
-            if (_.device('small')) return;
+            if (_.device('small') || capabilities.has('guest')) return;
             if (capabilities.has('guard-mail') || capabilities.has('guard-drive')) {
                 this.append(
                     this.link('GuardTour', gt('Guided tour for %s', window.oxguarddata.productName), function (e) {
