@@ -63,7 +63,7 @@ define('oxguard/settings/views/deletePrivateView', [
                 revoke.open(keyid);
             });
         })
-        .addButton()
+        .addCloseButton()
         .open();
         return dialog;
     }
