@@ -62,7 +62,7 @@ define('oxguard/settings/views/deletePrivateViewStep2', [
                 if (e && e.length > 1) yell('error', e);
             });
         })
-        .addButton()
+        .addCloseButton()
         .open();
     }
 
