@@ -60,7 +60,7 @@ define('oxguard/settings/views/deletePublicView', [
                 dialog.close();
             });
         })
-        .addButton()
+        .addCloseButton()
         .open();
     }
 
