@@ -42,7 +42,7 @@ define('oxguard/settings/views/downloadPrivateView', [
         })
         .build(function () {
         })
-        .addButton()
+        .addCloseButton()
         .open();
     }
 
@@ -126,20 +126,24 @@ define('oxguard/settings/views/downloadPrivateView', [
         var def = $.Deferred();
         core.getPassword(undefined, false)
         .done(function (pass) {
-            /// get the key
-            $('#guardTemp').remove(); // Clear any previous
-            core.metrics('settings', 'download-private');
-            var params = '&keyid=' + id +
-            '&keyType=' + (both ? 'public_private' : 'private') +
-            '&session=' + ox.session;
-            var link = ox.apiRoot + '/oxguard/keys?action=downloadKey' + params;
-            var form = $('<form method="POST" id="guardTemp" action="' + link + '" target="_blank">');
-            form.append($('<input type="hidden" name="password" value="' + pass.password + '">'));
-            $('#tmp').append(
-                form
-            );
-            def.resolve();
-            form.submit();
+            core.verifyPassword(pass.password, id).then(function () {
+                /// get the key
+                $('#guardTemp').remove(); // Clear any previous
+                core.metrics('settings', 'download-private');
+                var params = '&keyid=' + id +
+                '&keyType=' + (both ? 'public_private' : 'private') +
+                '&session=' + ox.session;
+                var link = ox.apiRoot + '/oxguard/keys?action=downloadKey' + params;
+                var form = $('<form method="POST" id="guardTemp" action="' + link + '" target="_blank">');
+                var input = $('<input type="hidden" name="password">');
+                input.attr('value', pass.password);
+                form.append(input);
+                $('#tmp').append(
+                    form
+                );
+                def.resolve();
+                form.submit();
+            }, def.reject);
         });
         return def;
     }
