@@ -336,6 +336,7 @@ define('oxguard/tour/main', [
                 model.once('send:ok', function () {
                     //HACK: no way to pause the wizard until some event
                     $('body').addClass('og-ready');
+                    $('.og_wait').hide();
                 });
                 window.setTimeout(function () {
                     if (_.device('desktop')) {
@@ -347,6 +348,7 @@ define('oxguard/tour/main', [
             })
             .on('next', function () {
                 model.send();
+                $('.wizard-container').append(view.$wait);
             })
             .end();
         }
@@ -383,7 +385,7 @@ define('oxguard/tour/main', [
                 //HACK: no way to pause the wizard until some event
                 $('body').removeClass('og-ready');
             })
-            .waitFor('.og-ready')
+            .waitFor('.og-ready', 30)
             .end()
         .start();
 
