@@ -11,9 +11,8 @@
      * provided with the application or distribution.
      */
 // jscs:disable
-define('pgp_local/base64', [
+define('pgp_local/base64', [], function () {
 
-], function () {
     'use strict';
 
     var b64s = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
