@@ -17,10 +17,7 @@
  * @param selector {string} the selector of an editable field
  * @param userIndex {number} the users position in the global users array
  */
-module.exports = function (selector, userIndex) {
-    if (!userIndex) userIndex = 0;
-    var users = global.users;
-    var user = users[userIndex];
+module.exports = function (selector, user) {
     this.clearField(selector);
     this.fillField(selector, user.password);
 
