@@ -14,6 +14,7 @@ module.exports = function () {
         changeTemporaryPassword: require('./commands/changeTemporaryPassword'),
         clickGuestLink: require('./commands/clickGuestLink'),
         setupUser: require('./commands/setupUser'),
-        goToSettings: require('./commands/gotoSettings')
+        goToSettings: require('./commands/gotoSettings'),
+        startEncryptedEmail: require('./commands/startEncryptedEmail')
     });
 };
