@@ -81,6 +81,48 @@ class GuardHelper extends Helper {
         page.keyboard.type(textToAdd);
     }
 
+    async selectEmailNumber(num) {
+        const { page } = this.helpers['Puppeteer'];
+        var selector = 'ul.list-view li:nth-child(' + (num + 1) + ')';
+        await page.$eval(selector, el => { el.click(); });
+    }
 
+    async openThreadEmail(num) {
+        const { page } = this.helpers['Puppeteer'];
+        return new Promise(function(resolve, reject) {
+            page.evaluate(function (num) {
+                var selector = '.multiple-messages article:nth-of-type(' + num +')';
+                var def = $.Deferred();
+                var attempts = 0;
+                function isOpen() {
+                    return $(selector + ' .content').is(':visible') || $(selector + ' .body').is(':visible');
+                }
+                function tryOpen(attempts) {
+                    console.log('attempting' + attempts);
+                    console.log(selector);
+                    console.log(selector + ' .toggle-mail-body');
+                    $(selector + ' .toggle-mail-body').click();
+                    setTimeout(function() {
+                        if (isOpen()) {
+                            def.resolve();
+                            return;
+                        }
+                        if (!isOpen() && attempts++ < 2) {
+                            tryOpen(attempts);
+                        }
+                        if (attempts > 2) {
+                            def.reject();
+                        }
+                    }, 500);
+                }
+                if (isOpen()) {
+                    def.resolve();
+                } else {
+                    tryOpen(0);
+                }
+                return def;
+            }, num).then(resolve, reject);
+        });
+    }
 }
 module.exports = GuardHelper;
\ No newline at end of file
