@@ -133,14 +133,5 @@ Scenario('Compose and email with PIN to guest user', async function (I, users) {
     I.waitForVisible('.mail-detail-frame');
     I.switchTo('.mail-detail-frame');
     I.see(data);
-    I.switchTo();
-
-    // Cleanup
-    // Guest link logout will bring this tab back to the recipient tab logged in
-    I.logout();
-    I.wait(1);
-    I.closeCurrentTab();
-    // Logout from Guest webmail
-    I.logout();
 
 });
