@@ -23,7 +23,7 @@ After(async function (users) {
     await users.removeAll();
 });
 
-Scenario('Compose and receive encrypted email', async function (I, users) {
+async function ComposeRecieve(I, users) {
     const o1 = {
         user: users[0]
     };
@@ -70,6 +70,15 @@ Scenario('Compose and receive encrypted email', async function (I, users) {
 
     // OK, done
     I.logout();
+}
+
+Scenario('Desktop: Compose and receive encrypted email, database composition space', async function (I, users) {
+    await users[0].hasConfig('com.openexchange.mail.compose.mailstorage.enabled', false);
+    await ComposeRecieve(I, users);
+});
+
+Scenario('Desktop: Compose and receive encrypted email, default composition space', async function (I, users) {
+    await ComposeRecieve(I, users);
 });
 
 // Testing sending in mobile views
