@@ -57,9 +57,9 @@ Scenario('Basic user only sees basic email wording', async function (I, users) {
     I.login('app=io.ox/mail', o);
     await I.verifyUserSetup(userdata);
     I.waitForVisible('.io-ox-mail-window .leftside');
-    I.startEncryptedEmail(userdata);
+    await I.startEncryptedEmail(userdata);
     I.waitForVisible('.info-line');
-    I.click('Options');
+    I.click('.security-options a');
     I.see('Sign email');
     I.dontSee('PGP Mime');
     I.dontSee('PGP Inline');
@@ -108,10 +108,10 @@ Scenario('Advanced user sees advanced email wording', async function (I, users)
     I.login('app=io.ox/mail', o);
     await I.verifyUserSetup(userdata);
     I.waitForVisible('.io-ox-mail-window .leftside');
-    I.startEncryptedEmail(userdata);
+    await I.startEncryptedEmail(userdata);
     
     I.waitForVisible('.info-line');
-    I.click('Options');
+    I.click('.security-options a');
 
     I.see('Security');
     I.see('Sign email');
