@@ -48,6 +48,7 @@ Scenario('First Setup and tour', async function (I, users) {
 
     // Try mismatched password and verify error
     I.insertCryptPassword('#newogpassword', userdata);
+    I.wait(1);
     I.fillField('#newogpassword2', 'mismatch');
     I.wait(1);
     I.see('Passwords not equal');
@@ -72,7 +73,7 @@ Scenario('First Setup and tour', async function (I, users) {
     I.executeScript(function () { if ($('[name="advanced"]').prop("checked")) { $('[name="advanced"]').click(); } })
 
     I.wait(1);
-    I.click('#io-ox-topbar-dropdown-icon > a.dropdown-toggle');
+    I.click('#io-ox-topbar-help-dropdown-icon > a.dropdown-toggle');
     I.click('a[data-name="GuardTour"]');
     I.waitForVisible('.window-blocker.io-ox-busy');
     I.waitForInvisible('.window-blocker.io-ox-busy');
