@@ -48,89 +48,38 @@ define('spec/shared/capabilities', [
                         }, def.reject);
                     }, def.reject);
 
-                    return def.then(function () {
-                        return data;
-                    });
-                },
-                /**
+                return def.then(function () {
+                    return data;
+                });
+            },
+            /**
                  * enable/disable capabilities
                  * @param  {array} list
                  * @param  {string} action [add|remove]
                  * @return {deferred}
                  */
-                process = function (list, action) {
-                    var before = [].concat(data);
-                    list = [].concat(list);
+            process = function (list, action) {
+                var before = [].concat(data);
+                list = [].concat(list);
 
-                    if (action === 'add') {
-                        data = _.unique(
-                            data.concat(list)
-                        );
-                    } else {
-                        data = _(data).difference(list);
-                    }
-
-                    //set
-                    return before.length === data.length ? $.Deferred().resolve(data) : apply();
-                };
-
-            return {
-                /**
-                 * @param  {string|array} ids of used modules
-                 * @param  {object|array} vars of used variables (analogous to 'ids')
-                 * @return {this}
-                 */
-                init: function (ids, vars) {
-                    references = {
-                        ids: [].concat(ids),
-                        vars: [].concat(vars)
-                    };
-                    return this;
-                },
-                /**
-                 * @return {array} capabilites
-                 */
-                get: function () {
-                    return [].concat(data);
-                },
-                /**
-                 * enable capabilities
-                 * @param  {string|array} list of capabilties
-                 * @return {deferred} returns current set of enabled capabilties (array)
-                 */
-                enable: function (list) {
-                    return process([].concat(list), 'add');
-                },
-                /**
-                 * disable capabilities
-                 * @param  {string|array} list of capabilties
-                 * @return {deferred} returns current set of enabled capabilties (array)
-                 */
-                disable: function (list) {
-                    return process([].concat(list), 'remove');
-                },
-                /**
-                 * reset to inital state of enabled caps (common, premium or pim)
-                 * @return {deferred} returns current set of enabled capabilties (array)
-                 */
-                reset: function () {
-                    data = base.slice(0);
-                    return apply();
-                },
-                /**
-                 * apply curret set of capabilities
-                 * @return {deferred} returns current set of enabled capabilties (array)
-                 */
-                apply: apply
+                if (action === 'add') {
+                    data = _.unique(
+                        data.concat(list)
+                    );
+                } else {
+                    data = _(data).difference(list);
+                }
 
+                //set
+                return before.length === data.length ? $.Deferred().resolve(data) : apply();
             };
 
         return {
             /**
-             * @param  {string|array} ids of used modules
-             * @param  {object|array} vars of used variables (analogous to 'ids')
-             * @return { this }
-             */
+                 * @param  {string|array} ids of used modules
+                 * @param  {object|array} vars of used variables (analogous to 'ids')
+                 * @return {this}
+                 */
             init: function (ids, vars) {
                 references = {
                     ids: [].concat(ids),
@@ -139,35 +88,41 @@ define('spec/shared/capabilities', [
                 return this;
             },
             /**
-             * @return { array} capabilites
-             */
+                 * @return {array} capabilites
+                 */
             get: function () {
                 return [].concat(data);
             },
             /**
-             * enable capabilities
-             * @param  {string|array} list of capabilties
-             * @return { deferred} returns current set of enabled capabilties (array)
-             */
+                 * enable capabilities
+                 * @param  {string|array} list of capabilties
+                 * @return {deferred} returns current set of enabled capabilties (array)
+                 */
             enable: function (list) {
                 return process([].concat(list), 'add');
             },
             /**
-             * disable capabilities
-             * @param  {string|array} list of capabilties
-             * @return { deferred} returns current set of enabled capabilties (array)
-             */
+                 * disable capabilities
+                 * @param  {string|array} list of capabilties
+                 * @return {deferred} returns current set of enabled capabilties (array)
+                 */
             disable: function (list) {
                 return process([].concat(list), 'remove');
             },
             /**
-             * reset to inital state of enabled caps (common, premium or pim)
-             * @return { deferred} returns current set of enabled capabilties (array)
-             */
+                 * reset to inital state of enabled caps (common, premium or pim)
+                 * @return {deferred} returns current set of enabled capabilties (array)
+                 */
             reset: function () {
                 data = base.slice(0);
                 return apply();
-            }
+            },
+            /**
+                 * apply curret set of capabilities
+                 * @return {deferred} returns current set of enabled capabilties (array)
+                 */
+            apply: apply
+
         };
     };
 
